Path Utilities :mod:`partis.pyproj.path`
========================================

.. automodule:: partis.pyproj.path.match

.. automodule:: partis.pyproj.path.utils

.. automodule:: partis.pyproj.path.pattern